==> custom_pages-v1.12.9.zip: custom_pages/messages/sv/model.php <==
<?php

return [
    'Abstract' => 'Sammanfattning',
    'Activate PHP based Pages and Snippets' => 'Aktivera PHP-baserade sidor och Snippets',
    'Attach Files' => 'Bifoga filer',
    'Content' => 'Innehåll',
    'Empty <br />Container' => 'Tom <br>behållare',
    'If disabled, existing php pages will still be online, but can\'t be created.' => 'Om inaktiverat kommer befintliga php-sidor fortfarande att vara online, men kan inte skapas.',
    'Label' => 'Etikett',
    'Open in new window' => 'Öppna i nytt fönster',
    'PHP view path for custom space pages' => 'PHP-visningsväg för anpassade nätverkssidor',
    'PHP view path for custom space snippets' => 'PHP sökväg för anpassade forum snippets',
    'PHP view path for global custom pages' => 'PHP sökväg för globala anpassade sidor',
    'PHP view path for global custom snippets' => 'PHP sökväg för globala anpassade snippets',
    'Placeholder name' => 'Namn för platshållare',
    'The element name must contain at least two characters without spaces or special signs except \'_\'' => 'Elementets namn måste innehålla minst två tecken utan mellanslag eller specialtecken utom \'_\'',
    'The given element name is already in use for this template.' => 'Det valda namnet för elementet används redan i den här mallen.',
    'The given view file path does not exist.' => 'Den givna sökvägen för filen finns inte.',
    'Url shortcut' => 'URL genväg',
    'View' => 'Visa',
    'Visibility' => 'Synlighet',
    'page' => 'sida',
    'snippet' => 'snippet',
    'Editors' => '',
    'Language-Based Visibility' => '',
    'Page-specific editors without full custom pages permission.' => '',
    'Visible to Group Members' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/sv/model.php <==
<?php

return [
    'Abstract' => 'Sammanfattning',
    'Activate PHP based Pages and Snippets' => 'Aktivera PHP-baserade sidor och Snippets',
    'Attach Files' => 'Bifoga filer',
    'Content' => 'Innehåll',
    'Empty <br />Container' => 'Tom <br>behållare',
    'If disabled, existing php pages will still be online, but can\'t be created.' => 'Om inaktiverat kommer befintliga php-sidor fortfarande att vara online, men kan inte skapas.',
    'Label' => 'Etikett',
    'Open in new window' => 'Öppna i nytt fönster',
    'PHP view path for custom space pages' => 'PHP-visningsväg för anpassade nätverkssidor',
    'PHP view path for custom space snippets' => 'PHP sökväg för anpassade forum snippets',
    'PHP view path for global custom pages' => 'PHP sökväg för globala anpassade sidor',
    'PHP view path for global custom snippets' => 'PHP sökväg för globala anpassade snippets',
    'Placeholder name' => 'Namn för platshållare',
    'The element name must contain at least two characters without spaces or special signs except \'_\'' => 'Elementets namn måste innehålla minst två tecken utan mellanslag eller specialtecken utom \'_\'',
    'The given element name is already in use for this template.' => 'Det valda namnet för elementet används redan i den här mallen.',
    'The given view file path does not exist.' => 'Den givna sökvägen för filen finns inte.',
    'Url shortcut' => 'URL genväg',
    'View' => 'Visa',
    'Visibility' => 'Synlighet',
    'page' => 'sida',
    'snippet' => 'snippet',
    'Editors' => '',
    'Hide in Navigation' => '',
    'Language-Based Visibility' => '',
    'Mobile App Users' => '',
    'Page-specific editors without full custom pages permission.' => '',
    'The element name is reserved, please choose another one.' => '',
    'Visible to Group Members' => '',
];
